This is an automated email from the ASF dual-hosted git repository.

sebbASF pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/whimsy.git


The following commit(s) were added to refs/heads/master by this push:
     new eab40e05 Drop Petri references
eab40e05 is described below

commit eab40e05018fffb0ba1c2d831c204ad7bb8d2d6c
Author: Sebb <[email protected]>
AuthorDate: Wed Jul 29 13:49:26 2026 +0100

    Drop Petri references
---
 lib/whimsy/asf.rb              |  1 -
 lib/whimsy/asf/git.rb          |  8 +++---
 lib/whimsy/asf/petri.rb        | 64 ------------------------------------------
 www/roster/main.rb             |  9 +-----
 www/roster/views/index.html.rb | 12 --------
 www/roster/views/petri.html.rb | 59 --------------------------------------
 6 files changed, 5 insertions(+), 148 deletions(-)

diff --git a/lib/whimsy/asf.rb b/lib/whimsy/asf.rb
index 322e74f3..30aa76fd 100644
--- a/lib/whimsy/asf.rb
+++ b/lib/whimsy/asf.rb
@@ -11,7 +11,6 @@ require_relative 'asf/icla'
 require_relative 'asf/documents'
 require_relative 'asf/auth'
 require_relative 'asf/member'
-require_relative 'asf/petri'
 require_relative 'asf/podling'
 require_relative 'asf/person'
 require_relative 'asf/themes'
diff --git a/lib/whimsy/asf/petri.rb b/lib/whimsy/asf/petri.rb
deleted file mode 100644
index 874b0235..00000000
--- a/lib/whimsy/asf/petri.rb
+++ /dev/null
@@ -1,64 +0,0 @@
-require 'yaml'
-require 'net/http'
-module ASF
-
-  PETRI_INFO = 'https://petri.apache.org/info.yaml'
-  # Represents a Petri culture
-  # currently defined in
-  # https://petri.apache.org/info.yaml
-  class Petri
-    include Enumerable
-
-    attr_reader :id
-    attr_reader :name
-    attr_reader :description
-    attr_reader :status
-    attr_reader :mentors
-    attr_reader :website
-    attr_reader :mailinglists
-    attr_reader :repository
-    attr_reader :issues
-    attr_reader :wiki
-    attr_reader :release
-    attr_reader :licensing
-    attr_accessor :error
-
-    def initialize(entry)
-      key, hash = entry
-      @id = key
-      hash.each { |name, value| instance_variable_set("@#{name}", value) }
-    end
-
-    # Array of all Petri culture entries
-    def self.list
-      @list = []
-      response = Net::HTTP.get_response(URI(PETRI_INFO))
-      response.value() # Raises error if not OK
-      yaml = YAML.safe_load(response.body, permitted_classes: [Symbol])
-      # @mentors = yaml['mentors']
-      yaml['cultures'].each do |proj|
-        prj = new(proj)
-        if yaml['projects'].include? proj
-          prj.error = 'Listed as a current project' unless prj.status == 
'current'
-        else
-          prj.error = 'Not listed as a current project' if prj.status == 
'current'
-        end
-        @list << prj
-      end
-      # Now check against projects listing
-      yaml['projects'].each do |proj|
-        unless yaml['cultures'].include? proj
-          @list << new([proj,{name: '', status: '', error: 'No culture entry 
found'}])
-        end
-      end
-      @list
-    end
-  end
-end
-
-if __FILE__ == $0
-  ASF::Petri.list.each do |e|
-    p e
-    p e.website
-  end
-end
diff --git a/www/roster/main.rb b/www/roster/main.rb
index 3c05c26f..3891872f 100755
--- a/www/roster/main.rb
+++ b/www/roster/main.rb
@@ -45,12 +45,10 @@ get '/' do
     @members = ASF::Member.list.keys - ASF::Member.status.keys # i.e. active 
member ids
     @groups = Group.list
     @podlings = ASF::Podling.to_h.values
-    @petri = ASF::Petri.list
     @otherids = ASF::Project.list.map(&:name) -
                 @committees.map(&:name) -
                 @nonpmcs.map(&:name) -
-                ASF::Podling.currentids -
-                @petri.map(&:id)
+                ASF::Podling.currentids
     _html :index
   else
     redirect to('/')
@@ -378,11 +376,6 @@ get '/podlings' do
   _html :podlings
 end
 
-get '/petri' do
-  @petri = ASF::Petri.list
-  _html :petri
-end
-
 # posted actions
 post '/actions/:file' do
   _json :"actions/#{params[:file]}"
diff --git a/www/roster/views/index.html.rb b/www/roster/views/index.html.rb
index 81500b3d..b905ba47 100644
--- a/www/roster/views/index.html.rb
+++ b/www/roster/views/index.html.rb
@@ -125,18 +125,6 @@ _html do
 
         end
 
-        _tr do
-          _td do
-            _a @petri.length, href: 'petri'
-          end
-
-          _td do
-            _a 'Petri', href: 'petri'
-          end
-
-          _td 'Petri cultures'
-        end
-
         # LDAP project groups without a PMC or active podling etc
         _tr do
           _td do
diff --git a/www/roster/views/petri.html.rb b/www/roster/views/petri.html.rb
deleted file mode 100644
index 8d0c2495..00000000
--- a/www/roster/views/petri.html.rb
+++ /dev/null
@@ -1,59 +0,0 @@
-#
-# List of all Podings
-#
-
-_html do
-  _link rel: 'stylesheet', href: "stylesheets/app.css?#{cssmtime}"
-  _style %{
-    p {margin-top: 0.5em}
-  }
-  _body? do
-    _whimsy_body(
-      title: 'ASF Petri Cultures',
-      breadcrumbs: {
-        roster: '.',
-        petri: 'petri'
-      }
-    ) do
-
-      _h2 'A listing of cultures from Apache Petri'
-      _p do
-        _ 'The data is derived from '
-        _a 'info.yaml', href: 'https://petri.apache.org/info.yaml'
-      end
-
-      _br
-
-      _h5 'Click on a column heading to change the sort order'
-
-      _table.table.table_hover do
-        _thead do
-          _tr do
-            _th.sorting_asc 'Id', data_sort: 'string-ins'
-            _th 'Name', data_sort: 'string'
-            _th 'Status', data_sort: 'string'
-            _th 'Error', data_sort: 'string'
-            _th 'Description', data_sort: 'string'
-          end
-        end
-        _tbody do
-          @petri.sort_by {|petri| petri.name.downcase}.each do |petri|
-            _tr do
-              _td do
-                _a petri.id, href: "https://petri.apache.org/#{petri.id}";
-              end
-              _td petri.name
-              _td petri.status
-              _td petri.error
-              _td petri.description
-            end
-          end
-        end
-      end
-    end
-
-    _script %{
-      $(".table").stupidtable();
-    }
-  end
-end

Reply via email to
diff --git a/lib/whimsy/asf/git.rb b/lib/whimsy/asf/git.rb
index c05633f6..3cc88a8d 100644
--- a/lib/whimsy/asf/git.rb
+++ b/lib/whimsy/asf/git.rb
@@ -13,7 +13,7 @@ module ASF
     # at GitHub.
     GITHUB_HOST = 'raw.githubusercontent.com'
 
     # get a file live from github, e.g. '/apache/petri/master/info.yaml'
     # returns body, status
     def self.github(file, _etag = nil)
       http = Net::HTTP.new(GITHUB_HOST, 443)
@@ -103,10 +103,10 @@ end
 
 if $0 == __FILE__
   require 'net/http'
-  c, b = ASF::Git.github('/apache/petri/master/info.yaml')
+  c, b = ASF::Git.github('/apache/whimsy/master/repository.yml')
   p c
   puts b[0..60]
-  c, b = ASF::Git.github('/apache/petri/master/missing.invalid')
+  c, b = ASF::Git.github('/apache/whimsy/master/missing.invalid')
   p c
-  puts b
+  puts b[0..60]
 end
@@ -13,7 +13,7 @@ module ASF
     GITHUB_HOST = 'raw.githubusercontent.com'
 
-    # get a file live from github, e.g. '/apache/petri/master/info.yaml'
+    # get a file live from github, e.g. '/apache/whimsy/master/repository.yml'
     # returns body, status
     def self.github(file, _etag = nil)